import PyPDF2
from pyluach import gematria
from tkinter import Tk, Label, Entry, Button, filedialog, messagebox

def add_bookmarks(filename, start_page=1, end_page=None):
    """
    פונקציה זו מוסיפה סימניות לקובץ PDF.

    Args:
        filename: שם קובץ ה-PDF.
        start_page: מספר העמוד ההתחלתי (ברירת מחדל: 1).
        end_page: מספר העמוד הסופי (ברירת מחדל: None, משמע עד סוף הקובץ).
    """
    
    # פתיחת קובץ ה-PDF
    with open(filename, 'rb') as f:
        reader = PyPDF2.PdfReader(f)
        writer = PyPDF2.PdfWriter()
        for page in reader.pages:
            writer.add_page(page)
    
        # קבלת מספר העמודים
        num_pages = len(reader.pages)
      
        # בדיקה אם end_page תקף
        if end_page is None or end_page > num_pages:
            end_page = num_pages
        
        # הוספת סימניות 
        bookname = filename.split('.')[0]
        root_outline = writer.add_outline_item(bookname, 0)

        for page_num in range(start_page, end_page + 1):
            real_page = page_num - start_page
            if (real_page % 2 == 0):
                bookmark_title = "דף " + gematria._get_letters(int((real_page + 4) / 2)) + "."
            else:
                bookmark_title = "דף " + gematria._get_letters(int((real_page + 3) / 2)) + ":"
            writer.add_outline_item(bookmark_title, page_num - 1, root_outline)

        # שמירת השינויים באותו הקובץ המקורי
        with open(filename, 'ab') as f:
            writer.write(f)

        messagebox.showinfo("הצלחה", "הסימניות נוספו בהצלחה לקובץ המקורי!")

# פונקציה לפתיחת סייר הקבצים לבחירת קובץ
def choose_file():
    file_path = filedialog.askopenfilename(filetypes=[("PDF files", "*.pdf")])
    file_entry.delete(0, "end")  # מחיקת הטקסט בתיבת הקלט הקיימת
    file_entry.insert(0, file_path)  # הכנסה של הנתיב הנבחר לתיבת הקלט

# פונקציה להפעלת הסקריפט עם הנתונים מהתיבות
def run_script():
    filename = file_entry.get()
    
    start_page = start_page_entry.get()
    start_page = int(start_page) if start_page else 1
    
    end_page = end_page_entry.get()
    end_page = int(end_page) if end_page else None
    
    if filename and start_page > 0 and (end_page is None or end_page >= start_page):
        add_bookmarks(filename, start_page, end_page)
    else:
        messagebox.showerror("שגיאה", "אנא הזן נתונים תקפים בכל השדות.")

# יצירת חלון ראשי
root = Tk()
root.title("הוספת סימניות ל-PDF")

# תוויות ושדות קלט
Label(root, text=" PDF בחר קובץ").grid(row=0, column=1, padx=10, pady=10, sticky="e")
file_entry = Entry(root, width=50)
file_entry.grid(row=0, column=0, padx=10, pady=10)
Button(root, text="בחר קובץ", command=choose_file).grid(row=0, column=2, padx=10, pady=10)

# הודעת הסבר למשתמש
Label(root, text="'להפעלת הסקריפט על כל הקובץ מתחילתו ועד סופו א\"צ למלאות את כל התיבות, לחץ עכשיו על 'הוסף סימניות").grid(row=1, column=0, columnspan=3, padx=10, pady=10)

Label(root, text=":מספר עמוד התחלתי").grid(row=2, column=2, padx=10, pady=10, sticky="w")
start_page_entry = Entry(root, width=10)
start_page_entry.grid(row=2, column=0, padx=10, pady=10)

Label(root, text=":מספר עמוד סופי").grid(row=3, column=2, padx=10, pady=10, sticky="w")
end_page_entry = Entry(root, width=10)
end_page_entry.grid(row=3, column=0, padx=10, pady=10)

# כפתור להרצת הסקריפט
Button(root, text="הוסף סימניות", command=run_script).grid(row=4, column=0, columnspan=3, pady=20)

# הפעלת החלון
root.mainloop()
